Introduction
============

Hopic was created to provide a relatively easy way to setup and maintain the configuration of CI systems.
In order to meet this goal it uses a simple `YAML <https://yaml.org/>` configuration file.
The configuration format is not based on a general purpose programming language in order to put a hard upper limit on the permitted amount of complexity.
